Reference
=========

.. toctree::
   :maxdepth: 1

   biso


.. currentmodule:: dibisoplot.biso

BiSO
----

.. autosummary::

   DataStatus
   get_hal_doc_type_name
   get_empty_plot_with_message
   get_empty_latex_with_message
   Biso.__init__
   Biso.generate_plot_info
   get_no_data_plot
   get_error_plot
   get_no_data_latex
   get_error_latex
   dataframe_to_longtable
   get_all_ids_with_cursor
   connect_to_elasticsearch
   get_works_from_es_index_from_id
   get_works_from_es_index_from_id_and_private_sector
   get_works_from_es_index_from_id_by_chunk
   Biso.get_figure
   AnrProjects.__init__
   AnrProjects.fetch_data
   Chapters.__init__
   Chapters.fetch_data
   Chapters.get_figure
   CollaborationMap.__init__
   CollaborationMap.fetch_data
   CollaborationMap.get_figure
   CollaborationNames.__init__
   CollaborationNames.fetch_data
   Conferences.__init__
   Conferences.fetch_data
   EuropeanProjects.__init__
   EuropeanProjects.fetch_data
   Journals.__init__
   Journals.fetch_data
   Journals.get_figure
   JournalsHal.__init__
   JournalsHal.fetch_data
   OpenAccessWorks.__init__
   OpenAccessWorks.fetch_data
   OpenAccessWorks.get_figure
   PrivateSectorCollaborations.__init__
   PrivateSectorCollaborations.fetch_data
   WorksBibtex.__init__
   WorksBibtex.fetch_data
   WorksBibtex.get_figure
   WorksType.__init__
   WorksType.fetch_data
